==> v4_navigation_engine-0.1.80.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/MyNavigationRouter.swift <==
//
//  MyNavigationRouter.swift
//  NavigationUI
//
//  Created Hassine on 10/03/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import UIKit
import MapboxDirections

/// MyNavigation Module Router (aka: Wireframe)
public class MyNavigationRouter: MyNavigationRouterProtocol {
        
          
      public init() {
          
      }

    public func createRunnincityNavigationController(route:Route) -> MyNavigationView {
          let controller = MyNavigationRouter.runnincityStoryboard.instantiateViewController(withIdentifier: "MyNavigationView") as! MyNavigationView
        // controller.userRoute = route
          controller.modalPresentationStyle = .fullScreen
        LocationService.shared.stopUpdatingLocation()
          return controller
      }

    public func createRunnincityNavigationController(coordinatesRoute:[CLLocationCoordinate2D],pois:[PointOfInterest]?,route:RouteInformation?,unitDistance:String) -> MyNavigationView {
             let controller = MyNavigationRouter.runnincityStoryboard.instantiateViewController(withIdentifier: "MyNavigationView") as! MyNavigationView
            controller.routeCoordinates = coordinatesRoute
        if coordinatesRoute.count >= 100
        {
            var coor = [CLLocationCoordinate2D]()
            var sub = coordinatesRoute[0...98]
            for c in sub
            {
                coor.append(c)
            }

            controller.routeCoordinates = coor
        }
        controller.routeInformation = route
        controller.pois = pois?.filter({ (p) -> Bool in
           return p.type != .directionnelHoraire &&  p.type != .directionnelAntiHoraire
        })
        if let pois = pois
        {
            controller.directionals =  pois.filter({ (p) -> Bool in
               return p.type == .directionnelHoraire 
            })
        }


        if unitDistance == "metric" {
            controller.measurementSystem = .metric
        } else if unitDistance == "imperial" {
            controller.measurementSystem = .imperial
        }
        
  

             controller.modalPresentationStyle = .fullScreen
     
        
             return controller
         }


    public func createPauseController() -> PauseRunViewController {
        let controller = MyNavigationRouter.runnincityStoryboard.instantiateViewController(withIdentifier: "PauseRunViewController") as! PauseRunViewController
         return controller
    }

    public func createPauseController(whiteLabel: WhiteLabel, gpsColor: String) -> PauseRunViewController {
        let controller = MyNavigationRouter.runnincityStoryboard.instantiateViewController(withIdentifier: "PauseRunViewController") as! PauseRunViewController
        controller.whiteLabel = whiteLabel
        controller.flutterGPSColor = gpsColor
         return controller
    }




    
    static var runnincityStoryboard: UIStoryboard {
        return UIStoryboard(name: "RunnincityNavigationView", bundle: Bundle.init(for: MyNavigationRouter.self))
    }

    
    
    // RaitingViewController
}

==> v4_navigation_engine-0.1.87.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/MyNavigationRouter.swift <==
//
//  MyNavigationRouter.swift
//  NavigationUI
//
//  Created Hassine on 10/03/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import UIKit
import MapboxDirections

/// MyNavigation Module Router (aka: Wireframe)
public class MyNavigationRouter: MyNavigationRouterProtocol {
        
          
      public init() {
          
      }

    public func createRunnincityNavigationController(route:Route) -> MyNavigationView {
          let controller = MyNavigationRouter.runnincityStoryboard.instantiateViewController(withIdentifier: "MyNavigationView") as! MyNavigationView
        // controller.userRoute = route
          controller.modalPresentationStyle = .fullScreen
        LocationService.shared.stopUpdatingLocation()
          return controller
      }

    public func createRunnincityNavigationController(coordinatesRoute:[CLLocationCoordinate2D],pois:[PointOfInterest]?,route:RouteInformation?,unitDistance:String) -> MyNavigationView {
             let controller = MyNavigationRouter.runnincityStoryboard.instantiateViewController(withIdentifier: "MyNavigationView") as! MyNavigationView
            controller.routeCoordinates = coordinatesRoute
        if coordinatesRoute.count >= 100
        {
            var coor = [CLLocationCoordinate2D]()
            var sub = coordinatesRoute[0...98]
            for c in sub
            {
                coor.append(c)
            }

            controller.routeCoordinates = coor
        }
        controller.routeInformation = route
        controller.pois = pois?.filter({ (p) -> Bool in
           return p.type != .directionnelHoraire &&  p.type != .directionnelAntiHoraire
        })
        controller.directionals = route?.directionals ?? []
        /*if let pois = pois
        {
            controller.directionals =  pois.filter({ (p) -> Bool in
                return p.type == .directionnelHoraire ||  p.type == .directionnelAntiHoraire || p.isDirectionnal == true
            })
        }*/


        if unitDistance == "metric" {
            controller.measurementSystem = .metric
        } else if unitDistance == "imperial" {
            controller.measurementSystem = .imperial
        }
        
  

             controller.modalPresentationStyle = .fullScreen
     
        
             return controller
         }


    public func createPauseController() -> PauseRunViewController {
        let controller = MyNavigationRouter.runnincityStoryboard.instantiateViewController(withIdentifier: "PauseRunViewController") as! PauseRunViewController
         return controller
    }

    public func createPauseController(whiteLabel: WhiteLabel, gpsColor: String) -> PauseRunViewController {
        let controller = MyNavigationRouter.runnincityStoryboard.instantiateViewController(withIdentifier: "PauseRunViewController") as! PauseRunViewController
        controller.whiteLabel = whiteLabel
        controller.flutterGPSColor = gpsColor
         return controller
    }




    
    static var runnincityStoryboard: UIStoryboard {
        return UIStoryboard(name: "RunnincityNavigationView", bundle: Bundle.init(for: MyNavigationRouter.self))
    }

    
    
    // RaitingViewController
}
